@@ -51,6 +51,7 @@ type RunContext struct {
 	Masks               []string
 	cleanUpJobContainer common.Executor
 	caller              *caller // job calling this RunContext (reusable workflows)
+	Cancelled           bool
 	nodeToolFullPath    string
 }
 
@@ -435,6 +436,8 @@ func (rc *RunContext) execJobContainer(cmd []string, env map[string]string, user
 
 func (rc *RunContext) InitializeNodeTool() common.Executor {
 	return func(ctx context.Context) error {
+		ctx, cancel := common.EarlyCancelContext(ctx)
+		defer cancel()
 		rc.GetNodeToolFullPath(ctx)
 		return nil
 	}
@@ -520,8 +523,16 @@ func (rc *RunContext) UpdateExtraPath(ctx context.Context, githubEnvPath string)
 		return err
 	}
 	s := bufio.NewScanner(reader)
+	firstLine := true
 	for s.Scan() {
 		line := s.Text()
+		if firstLine {
+			firstLine = false
+			// skip utf8 bom, powershell 5 legacy uses it for utf8
+			if len(line) >= 3 && line[0] == 239 && line[1] == 187 && line[2] == 191 {
+				line = line[3:]
+			}
+		}
 		if len(line) > 0 {
 			rc.addPath(ctx, line)
 		}
@@ -643,6 +654,8 @@ func (rc *RunContext) interpolateOutputs() common.Executor {
 
 func (rc *RunContext) startContainer() common.Executor {
 	return func(ctx context.Context) error {
+		ctx, cancel := common.EarlyCancelContext(ctx)
+		defer cancel()
 		if rc.IsHostEnv(ctx) {
 			return rc.startHostEnvironment()(ctx)
 		}
@@ -837,10 +850,14 @@ func trimToLen(s string, l int) string {
 
 func (rc *RunContext) getJobContext() *model.JobContext {
 	jobStatus := "success"
-	for _, stepStatus := range rc.StepResults {
-		if stepStatus.Conclusion == model.StepStatusFailure {
-			jobStatus = "failure"
-			break
+	if rc.Cancelled {
+		jobStatus = "cancelled"
+	} else {
+		for _, stepStatus := range rc.StepResults {
+			if stepStatus.Conclusion == model.StepStatusFailure {
+				jobStatus = "failure"
+				break
+			}
 		}
 	}
 	return &model.JobContext{
